# coding: utf-8

"""
    Arthur Scope

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from arthur_client.api_bindings.models.compliance_status import ComplianceStatus
from arthur_client.api_bindings.models.model_summary import ModelSummary
from arthur_client.api_bindings.models.policy import Policy
from typing import Optional, Set
from typing_extensions import Self

class PolicyAssignmentDetail(BaseModel):
    """
    PolicyAssignmentDetail
    """ # noqa: E501
    created_at: datetime = Field(description="Time of record creation.")
    updated_at: datetime = Field(description="Time of last record update.")
    id: StrictStr = Field(description="The ID of the policy assignment.")
    policy: Policy = Field(description="Full policy details.")
    model: ModelSummary = Field(description="Summary of the assigned model.")
    applied_at: datetime = Field(description="When the policy was applied to the model.")
    applied_by_user_id: Optional[StrictStr] = None
    grace_period_ends_at: datetime = Field(description="When the grace period ends.")
    compliance_status: ComplianceStatus = Field(description="Current compliance status.")
    compliance_job_id: Optional[StrictStr] = None
    __properties: ClassVar[List[str]] = ["created_at", "updated_at", "id", "policy", "model", "applied_at", "applied_by_user_id", "grace_period_ends_at", "compliance_status", "compliance_job_id"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of PolicyAssignmentDetail from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of policy
        if self.policy:
            _dict['policy'] = self.policy.to_dict()
        # override the default output from pydantic by calling `to_dict()` of model
        if self.model:
            _dict['model'] = self.model.to_dict()
        # set to None if applied_by_user_id (nullable) is None
        # and model_fields_set contains the field
        if self.applied_by_user_id is None and "applied_by_user_id" in self.model_fields_set:
            _dict['applied_by_user_id'] = None

        # set to None if compliance_job_id (nullable) is None
        # and model_fields_set contains the field
        if self.compliance_job_id is None and "compliance_job_id" in self.model_fields_set:
            _dict['compliance_job_id'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of PolicyAssignmentDetail from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "created_at": obj.get("created_at"),
            "updated_at": obj.get("updated_at"),
            "id": obj.get("id"),
            "policy": Policy.from_dict(obj["policy"]) if obj.get("policy") is not None else None,
            "model": ModelSummary.from_dict(obj["model"]) if obj.get("model") is not None else None,
            "applied_at": obj.get("applied_at"),
            "applied_by_user_id": obj.get("applied_by_user_id"),
            "grace_period_ends_at": obj.get("grace_period_ends_at"),
            "compliance_status": obj.get("compliance_status"),
            "compliance_job_id": obj.get("compliance_job_id")
        })
        return _obj


