# coding: utf-8

"""
    Arthur Scope

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from arthur_client.api_bindings.models.policy_assignment import PolicyAssignment

class TestPolicyAssignment(unittest.TestCase):
    """PolicyAssignment unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PolicyAssignment:
        """Test PolicyAssignment
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PolicyAssignment`
        """
        model = PolicyAssignment()
        if include_optional:
            return PolicyAssignment(
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                id = '',
                policy = arthur_client.api_bindings.models.policy_summary.PolicySummary(
                    id = '', 
                    name = '', ),
                model = arthur_client.api_bindings.models.model_summary.ModelSummary(
                    id = '', 
                    name = '', ),
                applied_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                applied_by_user_id = '',
                grace_period_ends_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                compliance_status = 'PENDING',
                compliance_job_id = ''
            )
        else:
            return PolicyAssignment(
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                id = '',
                policy = arthur_client.api_bindings.models.policy_summary.PolicySummary(
                    id = '', 
                    name = '', ),
                model = arthur_client.api_bindings.models.model_summary.ModelSummary(
                    id = '', 
                    name = '', ),
                applied_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                grace_period_ends_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                compliance_status = 'PENDING',
        )
        """

    def testPolicyAssignment(self):
        """Test PolicyAssignment"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
