# coding: utf-8

"""
    Arthur Scope

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from arthur_client.api_bindings.models.policy_assignment_detail import PolicyAssignmentDetail

class TestPolicyAssignmentDetail(unittest.TestCase):
    """PolicyAssignmentDetail unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PolicyAssignmentDetail:
        """Test PolicyAssignmentDetail
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PolicyAssignmentDetail`
        """
        model = PolicyAssignmentDetail()
        if include_optional:
            return PolicyAssignmentDetail(
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                id = '',
                policy = arthur_client.api_bindings.models.policy.Policy(
                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    id = '', 
                    organization_id = '', 
                    name = '', 
                    description = '', 
                    owner_group_id = '', 
                    webhook_id = '', 
                    grace_period_days = 56, 
                    alert_rules = [
                        arthur_client.api_bindings.models.policy_alert_rule.PolicyAlertRule(
                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            id = '', 
                            policy_id = '', 
                            name = '', 
                            description = '', 
                            threshold = 1.337, 
                            bound = 'upper_bound', 
                            query = '', 
                            metric_name = '', )
                        ], 
                    attestation_rules = [
                        arthur_client.api_bindings.models.policy_attestation_rule.PolicyAttestationRule(
                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            id = '', 
                            policy_id = '', 
                            name = '', 
                            description = '', 
                            interval_days = 56, )
                        ], 
                    last_updated_by_user_id = '', ),
                model = arthur_client.api_bindings.models.model_summary.ModelSummary(
                    id = '', 
                    name = '', ),
                applied_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                applied_by_user_id = '',
                grace_period_ends_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                compliance_status = 'PENDING',
                compliance_job_id = ''
            )
        else:
            return PolicyAssignmentDetail(
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                id = '',
                policy = arthur_client.api_bindings.models.policy.Policy(
                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    id = '', 
                    organization_id = '', 
                    name = '', 
                    description = '', 
                    owner_group_id = '', 
                    webhook_id = '', 
                    grace_period_days = 56, 
                    alert_rules = [
                        arthur_client.api_bindings.models.policy_alert_rule.PolicyAlertRule(
                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            id = '', 
                            policy_id = '', 
                            name = '', 
                            description = '', 
                            threshold = 1.337, 
                            bound = 'upper_bound', 
                            query = '', 
                            metric_name = '', )
                        ], 
                    attestation_rules = [
                        arthur_client.api_bindings.models.policy_attestation_rule.PolicyAttestationRule(
                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            id = '', 
                            policy_id = '', 
                            name = '', 
                            description = '', 
                            interval_days = 56, )
                        ], 
                    last_updated_by_user_id = '', ),
                model = arthur_client.api_bindings.models.model_summary.ModelSummary(
                    id = '', 
                    name = '', ),
                applied_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                grace_period_ends_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                compliance_status = 'PENDING',
        )
        """

    def testPolicyAssignmentDetail(self):
        """Test PolicyAssignmentDetail"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
