# coding: utf-8

"""
    Arthur Scope

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from arthur_client.api_bindings.api.workspaces_v1_api import WorkspacesV1Api


class TestWorkspacesV1Api(unittest.TestCase):
    """WorkspacesV1Api unit test stubs"""

    def setUp(self) -> None:
        self.api = WorkspacesV1Api()

    def tearDown(self) -> None:
        pass

    def test_delete_workspace(self) -> None:
        """Test case for delete_workspace

        Delete Workspace.
        """
        pass

    def test_get_workspace(self) -> None:
        """Test case for get_workspace

        Get Workspace.
        """
        pass

    def test_get_workspaces(self) -> None:
        """Test case for get_workspaces

        Get Workspaces.
        """
        pass

    def test_patch_workspace(self) -> None:
        """Test case for patch_workspace

        Patch Workspace.
        """
        pass

    def test_post_workspace(self) -> None:
        """Test case for post_workspace

        Post Workspace.
        """
        pass

    def test_workspace_get_statistics(self) -> None:
        """Test case for workspace_get_statistics

        Get Workspace Statistics
        """
        pass


if __name__ == '__main__':
    unittest.main()
